@@ -11,7 +11,7 @@ LOG = logging.getLogger(__name__)
 class Collections(AnsibleGalaxyBase):
     """Collection-specific Ansible Galaxy dependency handling."""
 
-    FILTER_OPTS = ("role-file", "roles-path")  # type: ignore
+    FILTER_OPTS = ("role-file",)  # type: ignore
     COMMANDS = ("collection", "install")
 
     @property
@@ -24,10 +24,6 @@ class Collections(AnsibleGalaxyBase):
                     self._config.scenario.directory,
                     "collections.yml",
                 ),
-                "collections-path": os.path.join(
-                    self._config.scenario.ephemeral_directory,
-                    "collections",
-                ),
             },
         )
 
@@ -35,15 +31,7 @@ class Collections(AnsibleGalaxyBase):
 
     @property
     def default_env(self):
-        general = super().default_env
-        return util.merge_dicts(
-            general,
-            {self._config.ansible_collections_path: self.install_path},
-        )
-
-    @property
-    def install_path(self):
-        return self.options["collections-path"]
+        return super().default_env
 
     @property
     def requirements_file(self):
