@@ -11,7 +11,7 @@ LOG = logging.getLogger(__name__)
 class Roles(AnsibleGalaxyBase):
     """Role-specific Ansible Galaxy dependency handling."""
 
-    FILTER_OPTS = ("requirements-file", "collections-path")  # type: ignore
+    FILTER_OPTS = ("requirements-file",)  # type: ignore
     COMMANDS = ("install",)
 
     @property
@@ -24,18 +24,10 @@ class Roles(AnsibleGalaxyBase):
                     self._config.scenario.directory,
                     "requirements.yml",
                 ),
-                "roles-path": os.path.join(
-                    self._config.scenario.ephemeral_directory,
-                    "roles",
-                ),
             },
         )
         return specific
 
-    @property
-    def install_path(self):
-        return os.path.join(self._config.scenario.directory, self.options["roles-path"])
-
     @property
     def requirements_file(self):
         return self.options["role-file"]
