@@ -24,7 +24,6 @@ import os
 from abc import ABCMeta, abstractmethod
 from importlib.metadata import version
 
-import molecule
 from molecule.status import Status
 
 
@@ -113,7 +112,7 @@ class Driver:
         """
 
     @abstractmethod
-    def sanity_checks(self):
+    def sanity_checks(self) -> None:
         """Confirm that driver is usable.
 
         Sanity checks to ensure the driver can do work successfully. For
@@ -148,11 +147,11 @@ class Driver:
 
     @property
     def delegated(self):
-        """Is the driver delegated and returns a bool.
+        """Is the dedriver delegated and returns a bool.
 
         :returns: bool
         """
-        return self.name == "delegated"
+        return self.name == "default"
 
     @property
     def managed(self):
@@ -240,21 +239,6 @@ class Driver:
         """Return rich representation of object."""
         return self.__str__()
 
-    def template_dir(self):
-        p = os.path.join(self._path, "cookiecutter")
-
-        if not os.path.isdir(p):
-            p = os.path.abspath(
-                os.path.join(
-                    os.path.dirname(molecule.__file__),
-                    "cookiecutter",
-                    "scenario",
-                    "driver",
-                    self.name,
-                ),
-            )
-        return p
-
     def get_playbook(self, step):
         """Return embedded playbook location or None.
 
