@@ -18,19 +18,16 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 """Molecule Utils Module."""
 
+from __future__ import annotations
 
-import contextlib
 import copy
 import fnmatch
 import logging
 import os
 import re
 import sys
-from collections.abc import Iterable, MutableMapping
-from dataclasses import dataclass
 from subprocess import CalledProcessError, CompletedProcess
-from typing import Any, NoReturn, Optional, Union
-from warnings import WarningMessage
+from typing import TYPE_CHECKING, Any, NoReturn
 
 import jinja2
 import yaml
@@ -41,6 +38,10 @@ from molecule.app import app
 from molecule.console import console
 from molecule.constants import MOLECULE_HEADER
 
+if TYPE_CHECKING:
+    from collections.abc import Iterable, MutableMapping
+    from warnings import WarningMessage
+
 LOG = logging.getLogger(__name__)
 
 
@@ -56,7 +57,7 @@ def print_debug(title: str, data: str) -> None:
     console.print(f"DEBUG: {title}:\n{data}")
 
 
-def print_environment_vars(env: Optional[dict[str, str]]) -> None:
+def print_environment_vars(env: dict[str, str | None] | None) -> None:
     """Print ``Ansible`` and ``Molecule`` environment variables and returns None.
 
     :param env: A dict containing the shell's environment as collected by
@@ -99,7 +100,7 @@ def sysexit(code: int = 1) -> NoReturn:
 def sysexit_with_message(
     msg: str,
     code: int = 1,
-    detail: Optional[MutableMapping] = None,
+    detail: MutableMapping | None = None,
     warns: Iterable[WarningMessage] = (),
 ) -> None:
     """Exit with an error message."""
@@ -108,7 +109,7 @@ def sysexit_with_message(
     if detail:
         detail_str = safe_dump(detail) if isinstance(detail, dict) else str(detail)
         print(detail_str)
-    LOG.critical(msg)
+    LOG.critical(msg, extra={"highlighter": False})
 
     for warn in warns:
         LOG.warning(warn.__dict__["message"].args[0])
@@ -116,7 +117,7 @@ def sysexit_with_message(
 
 
 def run_command(
-    cmd,
+    cmd: list[str],
     env=None,
     debug=False,
     echo=False,
@@ -128,20 +129,9 @@ def run_command(
 
     :param cmd: :
         - a string or list of strings (similar to subprocess.run)
-        - a BakedCommand object (
     :param debug: An optional bool to toggle debug output.
     """
-    args = []
-    if cmd.__class__.__name__ == "Command":
-        raise RuntimeError(
-            "Molecule 3.2.0 dropped use of sh library, update plugin code to use new API. "
-            "See https://github.com/ansible-community/molecule/issues/2678",
-        )
-    if cmd.__class__.__name__ == "BakedCommand":
-        env = dict(cmd.env, **env) if cmd.env and env else cmd.env or env
-        args = cmd.cmd
-    else:
-        args = cmd
+    args = cmd
 
     if debug:
         print_environment_vars(env)
@@ -186,7 +176,7 @@ def render_template(template, **kwargs):
     return t.render(kwargs)
 
 
-def write_file(filename: str, content: str, header: Optional[str] = None) -> None:
+def write_file(filename: str, content: str, header: str | None = None) -> None:
     """Write a file with the given filename and content and returns None.
 
     :param filename: A string containing the target filename.
@@ -197,7 +187,7 @@ def write_file(filename: str, content: str, header: Optional[str] = None) -> Non
     if header is None:
         content = MOLECULE_HEADER + "\n\n" + content
 
-    with open_file(filename, "w") as f:
+    with open(filename, "w") as f:
         f.write(content)
 
 
@@ -213,7 +203,7 @@ def file_prepender(filename: str) -> None:
     :param filename: A string containing the target filename.
     :return: None
     """
-    with open_file(filename, "r+") as f:
+    with open(filename, "r+") as f:
         content = f.read()
         f.seek(0, 0)
         f.write(molecule_prepender(content))
@@ -252,22 +242,10 @@ def safe_load_file(filename: str):
     :param filename: A string containing an absolute path to the file to parse.
     :return: dict
     """
-    with open_file(filename) as stream:
+    with open(filename) as stream:
         return safe_load(stream)
 
 
-@contextlib.contextmanager
-def open_file(filename, mode="r"):
-    """Open the provide file safely and returns a file type.
-
-    :param filename: A string containing an absolute path to the file to open.
-    :param mode: A string describing the way in which the file will be used.
-    :return: file type
-    """
-    with open(filename, mode) as stream:
-        yield stream
-
-
 def instance_with_scenario_name(instance_name, scenario_name):
     """Format instance name that includes scenario."""
     return f"{instance_name}-{scenario_name}"
@@ -294,7 +272,7 @@ def filter_verbose_permutation(options):
     return {k: options[k] for k in options if not re.match("^[v]+$", k)}
 
 
-def abs_path(path: str) -> Optional[str]:
+def abs_path(path: str) -> str | None:
     """Return absolute path."""
     if path:
         return os.path.abspath(path)
@@ -357,7 +335,7 @@ def find_vcs_root(location="", dirs=(".git", ".hg", ".svn"), default=None) -> st
     return default
 
 
-def lookup_config_file(filename: str) -> Optional[str]:
+def lookup_config_file(filename: str) -> str | None:
     """Return config file PATH."""
     for path in [find_vcs_root(default="~"), "~"]:
         f = os.path.expanduser(f"{path}/{filename}")
@@ -392,17 +370,6 @@ def boolean(value: Any, strict=True) -> bool:
     )
 
 
-@dataclass
-class BakedCommand:
-    """Define a subprocess command to be executed."""
-
-    cmd: Union[str, list[str]]
-    env: Optional[dict]
-    cwd: Optional[str] = None
-    stdout: Any = None
-    stderr: Any = None
-
-
 def dict2args(data: dict) -> list[str]:
     """Convert a dictionary of options to command like arguments."""
     result = []
